==> dstack-0.19.4rc3.tar.gz: dstack-0.19.4rc3/docs/blog/archive/ambassador-program.md <==
---
title: "Get involved as a community ambassador"
date: 2024-12-18
description: "Join dstack as an ambassador to grow the community, share knowledge, and help others use dstack."  
slug: ambassador-program
image: https://github.com/dstackai/static-assets/blob/main/static-assets/images/ambassador-program.png?raw=true
categories:
  - Community
---

# Get involved as a community ambassador 

As we wrap up an exciting year at `dstack`, we’re thrilled to introduce our Ambassador Program. This initiative invites AI
infrastructure enthusiasts and those passionate about open-source AI to share their knowledge, contribute to the growth
of the `dstack` community, and play a key role in advancing the open AI ecosystem.

[//]: # (What community is about:)
[//]: # (- Open-source)
[//]: # (- AI infrastructure)
[//]: # (- AI containers)
[//]: # (- Openness)

[//]: # (Mention:)
[//]: # (Who we are looking for)

<img src="https://github.com/dstackai/static-assets/blob/main/static-assets/images/ambassador-program.png?raw=true" width="630"/>

<!-- more -->

## What will you do as an ambassador?

As an ambassador, you’ll play a vital role in sharing best practices for using containers in AI workflows, advocating
for open-source tools for AI model training and inference, and helping the community use `dstack` with 
various cloud providers, data centers, and GPU vendors.

Your contributions might include writing technical blog posts, delivering talks, organizing `dstack` meetups, and
championing the open AI ecosystem within the broader community.

## Who is the program for?

Whether you’re new to `dstack` or already experienced, the ambassador program is open to anyone passionate 
about open-source AI, eager to share knowledge, and excited to engage with the AI community.

## How do we support ambassadors?

At `dstack`, we are committed to supporting ambassadors through recognition, amplifying their content, and providing
cloud GPU credits to power their projects.

## How to apply?

If you’re interested in becoming an ambassador, fill out a quick form with details about
yourself and your experience. We’ll reach out with a starter kit and next steps.

<a href="#" target="_blank"
   class="md-button md-button--primary sky small" 
    data-tally-open="3jGzb9"
    data-tally-overlay="1">
    Get involved
</a>

Have questions? Reach out via [Discord :material-arrow-top-right-thin:{ .external }](https://discord.gg/u8SmfwPpMd){:target="_blank"}!

> 💜 In the meantime, we’re thrilled to
> welcome [Park Chansung :material-arrow-top-right-thin:{ .external }](https://x.com/algo_diver){:target="_blank"}, the
> first `dstack` ambassador.

==> dstack-0.19.10.tar.gz: dstack-0.19.10/docs/blog/archive/ambassador-program.md <==
---
title: "Get involved as a community ambassador"
date: 2024-12-18
description: "Join dstack as an ambassador to grow the community, share knowledge, and help others use dstack."  
slug: ambassador-program
image: https://dstack.ai/static-assets/static-assets/images/ambassador-program.png
categories:
  - Community
---

# Get involved as a community ambassador 

As we wrap up an exciting year at `dstack`, we’re thrilled to introduce our Ambassador Program. This initiative invites AI
infrastructure enthusiasts and those passionate about open-source AI to share their knowledge, contribute to the growth
of the `dstack` community, and play a key role in advancing the open AI ecosystem.

[//]: # (What community is about:)
[//]: # (- Open-source)
[//]: # (- AI infrastructure)
[//]: # (- AI containers)
[//]: # (- Openness)

[//]: # (Mention:)
[//]: # (Who we are looking for)

<img src="https://dstack.ai/static-assets/static-assets/images/ambassador-program.png" width="630"/>

<!-- more -->

## What will you do as an ambassador?

As an ambassador, you’ll play a vital role in sharing best practices for using containers in AI workflows, advocating
for open-source tools for AI model training and inference, and helping the community use `dstack` with 
various cloud providers, data centers, and GPU vendors.

Your contributions might include writing technical blog posts, delivering talks, organizing `dstack` meetups, and
championing the open AI ecosystem within the broader community.

## Who is the program for?

Whether you’re new to `dstack` or already experienced, the ambassador program is open to anyone passionate 
about open-source AI, eager to share knowledge, and excited to engage with the AI community.

## How do we support ambassadors?

At `dstack`, we are committed to supporting ambassadors through recognition, amplifying their content, and providing
cloud GPU credits to power their projects.

## How to apply?

If you’re interested in becoming an ambassador, fill out a quick form with details about
yourself and your experience. We’ll reach out with a starter kit and next steps.

<a href="#" target="_blank"
   class="md-button md-button--primary sky small" 
    data-tally-open="3jGzb9"
    data-tally-overlay="1">
    Get involved
</a>

Have questions? Reach out via [Discord :material-arrow-top-right-thin:{ .external }](https://discord.gg/u8SmfwPpMd){:target="_blank"}!

> 💜 In the meantime, we’re thrilled to
> welcome [Park Chansung :material-arrow-top-right-thin:{ .external }](https://x.com/algo_diver){:target="_blank"}, the
> first `dstack` ambassador.
